@@ -34,6 +34,7 @@
 #include "libvex_basictypes.h"        // offsetof
 #include "guest_generic_bb_to_IR.h"   // DisResult
 #include "libvex_guest_s390x.h"       // VexGuestS390XState
+#include "main_util.h"                // STATIC_ASSERT
 
 
 /* Convert one s390 insn to IR.  See the type DisOneInstrFn in
@@ -89,9 +90,7 @@ UInt  s390_do_cvb(ULong decimal);
 ULong s390_do_cvd(ULong binary);
 ULong s390_do_ecag(ULong op2addr);
 UInt  s390_do_pfpo(UInt gpr0);
-void  s390x_dirtyhelper_PPNO_query(VexGuestS390XState *guest_state, ULong r1, ULong r2);
-ULong  s390x_dirtyhelper_PPNO_sha512(VexGuestS390XState *guest_state, ULong r1, ULong r2);
-void  s390x_dirtyhelper_PPNO_sha512_load_param_block( void );
+
 /* The various ways to compute the condition code. */
 enum {
    S390_CC_OP_BITWISE = 0,
@@ -156,7 +155,8 @@ enum {
    S390_CC_OP_PFPO_64 = 59,
    S390_CC_OP_PFPO_128 = 60,
    S390_CC_OP_MUL_32 = 61,
-   S390_CC_OP_MUL_64 = 62
+   S390_CC_OP_MUL_64 = 62,
+   S390_CC_OP_BITWISE2 = 63
 };
 
 /*------------------------------------------------------------*/
@@ -268,7 +268,6 @@ typedef enum {
    S390_VEC_OP_VPKS,
    S390_VEC_OP_VPKLS,
    S390_VEC_OP_VCEQ,
-   S390_VEC_OP_VTM,
    S390_VEC_OP_VGFM,
    S390_VEC_OP_VGFMA,
    S390_VEC_OP_VMAH,
