@@ -336,7 +336,7 @@ Intel_cache_info(Int level, VexCacheInfo *ci)
                }
                break;
             default:
-               VG_(debugLog)(1, "cache", "warning: L%u cache ignored\n",
+               VG_(debugLog)(1, "cache", "warning: L%d cache ignored\n",
                              (info[0] & 0xe0) >> 5);
                break;
             }
@@ -539,7 +539,8 @@ get_cache_info(VexArchInfo *vai)
 #elif defined(VGA_arm) || defined(VGA_ppc32)    || \
    defined(VGA_ppc64be) || defined(VGA_ppc64le) || \
    defined(VGA_mips32) || defined(VGA_mips64) || \
-   defined(VGA_arm64) || defined(VGA_nanomips)
+   defined(VGA_arm64) || defined(VGA_nanomips) || \
+   defined(VGA_riscv64)
 static Bool
 get_cache_info(VexArchInfo *vai)
 {
