@@ -48,7 +48,8 @@ ML_(new_dwarf3_reader) (
    DiSlice escn_debug_rnglists,  DiSlice escn_debug_loclists,
    DiSlice escn_debug_loc,       DiSlice escn_debug_info_alt,
    DiSlice escn_debug_abbv_alt,  DiSlice escn_debug_line_alt,
-   DiSlice escn_debug_str_alt,   DiSlice escn_debug_line_str
+   DiSlice escn_debug_str_alt,   DiSlice escn_debug_line_str,
+   DiSlice escn_debug_addr,      DiSlice escn_debug_str_offsets
 );
 
 #endif /* ndef __PRIV_READDWARF3_H */
