@@ -93,7 +93,7 @@
        memory that falls entirely inside the primary image.
 */
 
-Bool ML_(check_macho_and_get_rw_loads)( const void* buf, SizeT szB, Int* rw_loads )
+Bool ML_(check_macho_and_get_rw_loads)( Int fd, Int* rw_loads )
 {
    /* (JRS: the Mach-O headers might not be in this mapped data,
       because we only mapped a page for this initial check,
@@ -108,27 +108,35 @@ Bool ML_(check_macho_and_get_rw_loads)( const void* buf, SizeT szB, Int* rw_load
       can to establish whether or not we're looking at something
       sane. */
 
-   /* @todo PJF change function signature to pass in file handle
-        Read MACH_HEADER to determine sizeofcommands
-       Allocate a dynamic buffer for the commands. */
+   HChar macho_header[sizeof(struct MACH_HEADER)];
+   SysRes preadres = VG_(pread)( fd, macho_header, sizeof(struct MACH_HEADER), 0 );
 
-   const struct fat_header*  fh_be = buf;
-   const struct MACH_HEADER* mh    = buf;
-
-   vg_assert(buf);
-   vg_assert(rw_loads);
-   if (szB < sizeof(struct fat_header))
+   if (sr_isError(preadres) || sr_Res(preadres) < sizeof(struct MACH_HEADER)) {
       return False;
+   }
+
+   const struct fat_header*  fh_be = (const struct fat_header*)macho_header;
+   const struct MACH_HEADER* mh    = (const struct MACH_HEADER*)macho_header;
+
+   vg_assert(fh_be);
+   vg_assert(mh);
+   vg_assert(rw_loads);
+   STATIC_ASSERT(sizeof(struct fat_header) <= sizeof(struct MACH_HEADER));
    if (VG_(ntohl)(fh_be->magic) == FAT_MAGIC) {
       // @todo PJF not yet handled, previous behaviour was to assume that the count is 1
       *rw_loads = 1;
       return True;
    }
 
-   if (szB < sizeof(struct MACH_HEADER))
-      return False;
    if (mh->magic == MAGIC) {
-      const struct load_command* lc = (const struct load_command*)((const char*)buf + sizeof(struct MACH_HEADER));
+      HChar* macho_load_commands = ML_(dinfo_zalloc)("di.readmacho.macho_load_commands", mh->sizeofcmds);
+      preadres = VG_(pread)( fd, macho_load_commands, mh->sizeofcmds, sizeof(struct MACH_HEADER) );
+      if (sr_isError(preadres) || sr_Res(preadres) < mh->sizeofcmds) {
+         ML_(dinfo_free)(macho_load_commands);
+         return False;
+      }
+
+      const struct load_command* lc = (const struct load_command*)macho_load_commands;
       for (unsigned int i = 0U; i < mh->ncmds; ++i) {
          if (lc->cmd == LC_SEGMENT_CMD) {
             const struct SEGMENT_COMMAND* sc = (const struct SEGMENT_COMMAND*)lc;
@@ -139,6 +147,7 @@ Bool ML_(check_macho_and_get_rw_loads)( const void* buf, SizeT szB, Int* rw_load
          const char* tmp = (const char*)lc + lc->cmdsize;
          lc = (const struct load_command*)tmp;
       }
+      ML_(dinfo_free)(macho_load_commands);
       return True;
    }
 
