@@ -47,9 +47,11 @@
 #define free(_pt)            VG_(arena_free)   (VG_AR_DEMANGLE,(_pt))
 #define memcmp(_s1,_s2,_sz)  VG_(memcmp)((_s1),(_s2),(_sz))
 #define memcpy(_dd,_ss,_sz)  VG_(memcpy)((_dd),(_ss),(_sz))
+#define memmove(_dd,_ss,_sz) VG_(memmove)((_dd),(_ss),(_sz))
 #define memset(_ss,_cc,_sz)  VG_(memset)((_ss),(_cc),(_sz))
 #define realloc(_cc,_pt,_sz) VG_(arena_realloc)(VG_AR_DEMANGLE,(_cc),(_pt),(_sz))
-#define sprintf(_buf,_fmt,_args...)  VG_(sprintf)((_buf),(_fmt),(_args))
+#define sprintf(_buf,_fmt,_args...) VG_(sprintf)((_buf),(_fmt),(_args))
+#define snprintf(_buf,_size,_fmt,_args...) VG_(snprintf)((_buf),(_size),(_fmt),(_args))
 #define strcat(_dd,_ss)      VG_(strcat)((_dd),(_ss))
 #define strchr(_ss,_cc)      VG_(strchr)((_ss),(_cc))
 #define strcmp(_s1,_s2)      VG_(strcmp)((_s1),(_s2))
