@@ -61,7 +61,6 @@ static void load_client ( /*OUT*/ExeInfo* info,
 {
    const HChar* exe_name;
    Int    ret;
-   SysRes res;
 
    vg_assert( VG_(args_the_exename) != NULL);
    exe_name = VG_(find_executable)( VG_(args_the_exename) );
@@ -76,12 +75,6 @@ static void load_client ( /*OUT*/ExeInfo* info,
 
    // The client was successfully loaded!  Continue.
 
-   /* Get hold of a file descriptor which refers to the client
-      executable.  This is needed for attaching to GDB. */
-   res = VG_(open)(exe_name, VKI_O_RDONLY, VKI_S_IRUSR);
-   if (!sr_isError(res))
-      VG_(cl_exec_fd) = sr_Res(res);
-
    /* Copy necessary bits of 'info' that were filled in */
    *client_ip  = info->init_ip;
 }
