@@ -7,7 +7,7 @@
    This file is part of Valgrind, a dynamic binary instrumentation
    framework.
 
-   Copyright (C) 2000-2015 Julian Seward 
+   Copyright (C) 2000-2017 Julian Seward 
       jseward@acm.org
 
    This program is free software; you can redistribute it and/or
@@ -21,9 +21,7 @@
    General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-   02111-1307, USA.
+   along with this program; if not, see <http://www.gnu.org/licenses/>.
 
    The GNU General Public License is contained in the file COPYING.
 */
@@ -266,6 +264,14 @@ SizeT VG_(strlen) ( const HChar* str )
    return i;
 }
 
+SizeT VG_(strnlen)(const HChar* str, SizeT n)
+{
+   SizeT i = 0;
+   while (i < n && str[i] != 0)
+      i++;
+   return i;
+}
+
 HChar* VG_(strcat) ( HChar* dest, const HChar* src )
 {
    HChar* dest_orig = dest;
@@ -319,6 +325,29 @@ HChar* VG_(strncpy) ( HChar* dest, const HChar* src, SizeT ndest )
    }
 }
 
+/* Copies up to n-1 bytes from src to dst. Then nul-terminate dst if n > 0.
+   Returns strlen(src). Does not zero-fill the remainder of dst. */
+SizeT VG_(strlcpy)(HChar *dst, const HChar *src, SizeT n)
+{
+   const HChar *src_orig = src;
+   SizeT m = 0;
+
+   while (m < n - 1 && *src != '\0') {
+      m++;
+      *dst++ = *src++;
+   }
+
+   /* Nul-terminate dst. */ \
+   if (n > 0)
+      *dst = 0;
+
+   /* Finish counting strlen(src). */ \
+   while (*src != '\0')
+      src++;
+
+   return src - src_orig;
+}
+
 Int VG_(strcmp) ( const HChar* s1, const HChar* s2 )
 {
    while (True) {
@@ -722,24 +751,26 @@ void* VG_(memset) ( void *destV, Int c, SizeT sz )
       d++;
       sz--;
    }
+   UInt* d4 = ASSUME_ALIGNED(UInt*, d);
    if (sz == 0)
       return destV;
    c4 = uc;
    c4 |= (c4 << 8);
    c4 |= (c4 << 16);
    while (sz >= 16) {
-      ((UInt*)d)[0] = c4;
-      ((UInt*)d)[1] = c4;
-      ((UInt*)d)[2] = c4;
-      ((UInt*)d)[3] = c4;
-      d += 16;
+      d4[0] = c4;
+      d4[1] = c4;
+      d4[2] = c4;
+      d4[3] = c4;
+      d4 += 4;
       sz -= 16;
    }
    while (sz >= 4) {
-      ((UInt*)d)[0] = c4;
-      d += 4;
+      d4[0] = c4;
+      d4 += 1;
       sz -= 4;
    }
+   d = (UChar*) d4;
    while (sz >= 1) {
       d[0] = c;
       d++;
@@ -793,7 +824,8 @@ Int VG_(memcmp) ( const void* s1, const void* s2, SizeT n )
 #define BM_SWAP(a, b)                                    \
    swaptype != 0                                         \
       ? bm_swapfunc(a, b, es, swaptype)                  \
-      : (void)BM_EXCH(*(Word*)(a), *(Word*)(b), t)
+      : (void)BM_EXCH(*ASSUME_ALIGNED(Word*, (a)),       \
+                      *ASSUME_ALIGNED(Word*, (b)), t)
 
 #define BM_VECSWAP(a, b, n)                              \
    if (n > 0) bm_swapfunc(a, b, n, swaptype)
@@ -802,7 +834,7 @@ Int VG_(memcmp) ( const void* s1, const void* s2, SizeT n )
    if (swaptype != 0)                                    \
       pv = a, BM_SWAP(pv, pm);                           \
    else                                                  \
-      pv = (Char*)&v, v = *(Word*)pm
+      pv = (Char*)&v, v = *ASSUME_ALIGNED(Word*, pm)
 
 static Char* bm_med3 ( Char* a, Char* b, Char* c, 
                        Int (*cmp)(const void*, const void*) ) {
@@ -817,7 +849,7 @@ static void bm_swapfunc ( Char* a, Char* b, SizeT n, Int swaptype )
       Word t;
       for ( ; n > 0; a += sizeof(Word), b += sizeof(Word),
                                         n -= sizeof(Word))
-         BM_EXCH(*(Word*)a, *(Word*)b, t);
+         BM_EXCH(*ASSUME_ALIGNED(Word*, a), *ASSUME_ALIGNED(Word*, b), t);
    } else {
       Char t;
       for ( ; n > 0; a += 1, b += 1, n -= 1)
