@@ -592,7 +592,7 @@ DECL_TEMPLATE(darwin, fstatat64);                // 470
 // NYI unlinkat        // 472
 DECL_TEMPLATE(darwin, readlinkat);               // 473
 // NYI symlinkat       // 474
-// NYI mkdirat         // 475
+DECL_TEMPLATE(darwin,  mkdirat);                 // 475
 // NYI getattrlistat   // 476
 // NYI proc_trace_log  // 477
 DECL_TEMPLATE(darwin, bsdthread_ctl);            // 478
