@@ -538,7 +538,10 @@ DECL_TEMPLATE(freebsd, sys_timerfd_settime) // 587
 
 // __FreeBSD_version 1400507 and 1500012
 DECL_TEMPLATE(freebsd, sys_kcmp) // 588
+
 DECL_TEMPLATE(freebsd, sys_getrlimitusage) // 589
+DECL_TEMPLATE(freebsd, sys_fchroot) // 590
+DECL_TEMPLATE(freebsd, sys_setcred) // 591
 
 DECL_TEMPLATE(freebsd, sys_fake_sigreturn)
 
