@@ -814,18 +814,29 @@ static SyscallTableEntry syscall_main_table[] = {
    LINX_ (__NR_syncfs, sys_syncfs),
    LINXY (__NR_statx, sys_statx),
    GENX_ (__NR_rseq, sys_ni_syscall),
+   LINX_ (__NR_io_pgetevents, sys_io_pgetevents),
    LINX_ (__NR_setns, sys_setns),
    LINXY (__NR_io_uring_setup, sys_io_uring_setup),
    LINXY (__NR_io_uring_enter, sys_io_uring_enter),
    LINXY (__NR_io_uring_register, sys_io_uring_register),
+   LINXY (__NR_open_tree, sys_open_tree),
+   LINX_ (__NR_move_mount, sys_move_mount),
+   LINXY (__NR_fsopen, sys_fsopen),
+   LINX_ (__NR_fsconfig, sys_fsconfig),
+   LINXY (__NR_fsmount, sys_fsmount),
+   LINXY (__NR_fspick, sys_fspick),
    LINXY (__NR_pidfd_open, sys_pidfd_open),
    GENX_ (__NR_clone3, sys_ni_syscall),
    LINXY (__NR_close_range, sys_close_range),
    LINXY (__NR_openat2, sys_openat2),
    LINXY (__NR_pidfd_getfd, sys_pidfd_getfd),
    LINX_ (__NR_faccessat2, sys_faccessat2),
-   LINXY(__NR_epoll_pwait2, sys_epoll_pwait2),
+   LINXY (__NR_epoll_pwait2, sys_epoll_pwait2),
+   LINXY (__NR_landlock_create_ruleset, sys_landlock_create_ruleset),
+   LINX_ (__NR_landlock_add_rule, sys_landlock_add_rule),
+   LINX_ (__NR_landlock_restrict_self, sys_landlock_restrict_self),
    LINX_ (__NR_fchmodat2, sys_fchmodat2),
+   LINXY (__NR_userfaultfd, sys_userfaultfd),
 };
 
 SyscallTableEntry * ML_(get_linux_syscall_entry) ( UInt sysno )
