@@ -812,7 +812,7 @@ static SyscallTableEntry syscall_main_table[] = {
    LINX_ (__NR_setns,                  sys_setns),
    //    (__NR_bpf,                    sys_ni_syscall),
    LINX_ (__NR_execveat,               sys_execveat),
-   //    (__NR_userfaultfd,            sys_ni_syscall),
+   LINXY (__NR_userfaultfd,            sys_userfaultfd),
    LINX_ (__NR_membarrier,             sys_membarrier),
    GENX_ (__NR_mlock2,                 sys_mlock2),
    //    (__NR_copy_file_range,        sys_ni_syscall),
@@ -824,6 +824,12 @@ static SyscallTableEntry syscall_main_table[] = {
    LINXY (__NR_io_uring_setup,         sys_io_uring_setup),
    LINXY (__NR_io_uring_enter,         sys_io_uring_enter),
    LINXY (__NR_io_uring_register,      sys_io_uring_register),
+   LINXY (__NR_open_tree,              sys_open_tree),
+   LINX_ (__NR_move_mount,             sys_move_mount),
+   LINXY (__NR_fsopen,                 sys_fsopen),
+   LINX_ (__NR_fsconfig,               sys_fsconfig),
+   LINXY (__NR_fsmount,                sys_fsmount),
+   LINXY (__NR_fspick,                 sys_fspick),
    LINXY (__NR_pidfd_open,             sys_pidfd_open),
    GENX_ (__NR_clone3,                 sys_ni_syscall),
    LINXY (__NR_close_range,            sys_close_range),
@@ -831,6 +837,9 @@ static SyscallTableEntry syscall_main_table[] = {
    LINXY(__NR_pidfd_getfd,             sys_pidfd_getfd),
    LINX_ (__NR_faccessat2,             sys_faccessat2),
    LINXY (__NR_epoll_pwait2,           sys_epoll_pwait2),
+   LINXY (__NR_landlock_create_ruleset,sys_landlock_create_ruleset),
+   LINX_ (__NR_landlock_add_rule,      sys_landlock_add_rule),
+   LINX_ (__NR_landlock_restrict_self, sys_landlock_restrict_self),
    LINX_ (__NR_fchmodat2,              sys_fchmodat2),
 };
 
