@@ -7,7 +7,7 @@
    This file is part of Valgrind, a dynamic binary instrumentation
    framework.
 
-   Copyright (C) 2011-2015 Petr Pavlu
+   Copyright (C) 2011-2017 Petr Pavlu
       setup@dagobah.cz
 
    This program is free software; you can redistribute it and/or
@@ -21,9 +21,7 @@
    General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-   02111-1307, USA.
+   along with this program; if not, see <http://www.gnu.org/licenses/>.
 
    The GNU General Public License is contained in the file COPYING.
 */
@@ -576,7 +574,7 @@ void ML_(cleanup_gdt)(VexGuestX86State *vex)
 {
    if (!vex->guest_GDT)
       return;
-   VG_(free)((void*)vex->guest_GDT);
+   VG_(free)((void *) (HWord) vex->guest_GDT);
    vex->guest_GDT = 0;
 }
 
@@ -586,7 +584,8 @@ void ML_(update_gdt_lwpgs)(ThreadId tid)
 {
    ThreadState *tst = VG_(get_ThreadState)(tid);
    Addr base = tst->os_state.thrptr;
-   VexGuestX86SegDescr *gdt = (VexGuestX86SegDescr*)tst->arch.vex.guest_GDT;
+   VexGuestX86SegDescr *gdt
+      = (VexGuestX86SegDescr *) (HWord) tst->arch.vex.guest_GDT;
    VexGuestX86SegDescr desc;
 
    vg_assert(gdt);
@@ -972,6 +971,7 @@ PRE(sys_open64)
 
 POST(sys_open64)
 {
+   POST_newFd_RES;
    if (!ML_(fd_allowed)(RES, "open64", tid, True)) {
       VG_(close)(RES);
       SET_STATUS_Failure(VKI_EMFILE);
