@@ -221,9 +221,13 @@ Bool VG_(finish_needs_init)(const HChar** failmsg)
 // These ones don't require any tool-supplied functions
 NEEDS(libc_freeres)
 NEEDS(cxx_freeres)
-NEEDS(core_errors)
 NEEDS(var_info)
 
+void VG_(needs_core_errors)( Bool need )
+{
+   VG_(needs).core_errors = need;
+}
+
 void VG_(needs_superblock_discards)(
    void (*discard)(Addr, VexGuestExtents)
 )
