@@ -92,10 +92,10 @@ typedef UShort HTTno;
    address range which does not fall cleanly within any specific bin.
    Note that ECLASS_SHIFT + ECLASS_WIDTH must be < 32.
    ECLASS_N must fit in a EclassNo. */
-#define ECLASS_SHIFT 13
-#define ECLASS_WIDTH 9
-#define ECLASS_MISC  (1 << ECLASS_WIDTH)
-#define ECLASS_N     (1 + ECLASS_MISC)
+#define ECLASS_SHIFT 13U
+#define ECLASS_WIDTH 9U
+#define ECLASS_MISC  (1U << ECLASS_WIDTH)
+#define ECLASS_N     (1U + ECLASS_MISC)
 STATIC_ASSERT(ECLASS_SHIFT + ECLASS_WIDTH < 32);
 
 typedef UShort EClassNo;
@@ -1152,7 +1152,7 @@ UInt addEClassNo ( /*MOD*/Sector* sec, EClassNo ec, TTEno tteno )
    Int    old_sz, new_sz, i, r;
    TTEno  *old_ar, *new_ar;
 
-   vg_assert(ec >= 0 && ec < ECLASS_N);
+   vg_assert(ec < ECLASS_N);
    vg_assert(tteno < N_TTES_PER_SECTOR);
 
    if (DEBUG_TRANSTAB) VG_(printf)("ec %d  gets %d\n", ec, (Int)tteno);
@@ -1192,7 +1192,7 @@ void upd_eclasses_after_add ( /*MOD*/Sector* sec, TTEno tteno )
 {
    Int i, r;
    EClassNo eclasses[3];
-   vg_assert(tteno >= 0 && tteno < N_TTES_PER_SECTOR);
+   vg_assert(tteno < N_TTES_PER_SECTOR);
 
    TTEntryH* tteH = &sec->ttH[tteno];
    r = vexGuestExtents_to_eclasses( eclasses, tteH );
@@ -1264,7 +1264,7 @@ static Bool sanity_check_eclasses_in_sector ( const Sector* sec )
                 && tteC->tte2ec_ec[k] >= tteC->tte2ec_ec[k+1])
                BAD("tteC->tte2ec_ec[..] out of order");
             ec_num = tteC->tte2ec_ec[k];
-            if (ec_num < 0 || ec_num >= ECLASS_N)
+            if (ec_num >= ECLASS_N)
                BAD("tteC->tte2ec_ec[..] out of range");
             if (ec_num != i)
                continue;
@@ -1303,7 +1303,7 @@ static Bool sanity_check_eclasses_in_sector ( const Sector* sec )
 
       for (j = 0; j < tteC->n_tte2ec; j++) {
          ec_num = tteC->tte2ec_ec[j];
-         if (ec_num < 0 || ec_num >= ECLASS_N)
+         if (ec_num >= ECLASS_N)
             BAD("tteC->tte2ec_ec[..] out of range");
          ec_idx = tteC->tte2ec_ix[j];
          if (ec_idx < 0 || ec_idx >= sec->ec2tte_used[ec_num])
@@ -1530,7 +1530,7 @@ static TTEno get_empty_tt_slot(SECno sNo)
    i = sectors[sNo].empty_tt_list;
    sectors[sNo].empty_tt_list = sectors[sNo].ttC[i].usage.next_empty_tte;
 
-   vg_assert (i >= 0 && i < N_TTES_PER_SECTOR);
+   vg_assert (i < N_TTES_PER_SECTOR);
 
    return i;
 }
@@ -1574,7 +1574,7 @@ static void initialiseSector ( SECno sno )
       sres = VG_(am_mmap_anon_float_valgrind)( 8 * tc_sector_szQ );
       if (sr_isError(sres)) {
          VG_(out_of_memory_NORETURN)("initialiseSector(TC)", 
-                                     8 * tc_sector_szQ );
+                                     8 * tc_sector_szQ, sr_Err(sres) );
 	 /*NOTREACHED*/
       }
       sec->tc = (ULong*)(Addr)sr_Res(sres);
@@ -1583,7 +1583,8 @@ static void initialiseSector ( SECno sno )
                 ( N_TTES_PER_SECTOR * sizeof(TTEntryC) );
       if (sr_isError(sres)) {
          VG_(out_of_memory_NORETURN)("initialiseSector(TTC)", 
-                                     N_TTES_PER_SECTOR * sizeof(TTEntryC) );
+                                     N_TTES_PER_SECTOR * sizeof(TTEntryC),
+                                     sr_Err(sres));
 	 /*NOTREACHED*/
       }
       sec->ttC = (TTEntryC*)(Addr)sr_Res(sres);
@@ -1592,7 +1593,8 @@ static void initialiseSector ( SECno sno )
                 ( N_TTES_PER_SECTOR * sizeof(TTEntryH) );
       if (sr_isError(sres)) {
          VG_(out_of_memory_NORETURN)("initialiseSector(TTH)", 
-                                     N_TTES_PER_SECTOR * sizeof(TTEntryH) );
+                                     N_TTES_PER_SECTOR * sizeof(TTEntryH),
+                                     sr_Err(sres));
 	 /*NOTREACHED*/
       }
       sec->ttH = (TTEntryH*)(Addr)sr_Res(sres);
@@ -1608,7 +1610,8 @@ static void initialiseSector ( SECno sno )
                 ( N_HTTES_PER_SECTOR * sizeof(TTEno) );
       if (sr_isError(sres)) {
          VG_(out_of_memory_NORETURN)("initialiseSector(HTT)", 
-                                     N_HTTES_PER_SECTOR * sizeof(TTEno) );
+                                     N_HTTES_PER_SECTOR * sizeof(TTEno),
+                                     sr_Err(sres));
 	 /*NOTREACHED*/
       }
       sec->htt = (TTEno*)(Addr)sr_Res(sres);
@@ -1622,11 +1625,11 @@ static void initialiseSector ( SECno sno )
                       sizeof(HostExtent));
 
       /* Add an entry in the sector_search_order */
-      for (i = 0; i < n_sectors; i++) {
+      for (i = 0U; i < n_sectors; i++) {
          if (sector_search_order[i] == INV_SNO)
             break;
       }
-      vg_assert(i >= 0 && i < n_sectors);
+      vg_assert(i < n_sectors);
       sector_search_order[i] = sno;
 
       if (VG_(clo_verbosity) > 2)
@@ -1707,7 +1710,7 @@ static void initialiseSector ( SECno sno )
          if (sector_search_order[ix] == sno)
             break;
       }
-      vg_assert(ix >= 0 && ix < n_sectors);
+      vg_assert(ix < n_sectors);
 
       if (VG_(clo_verbosity) > 2)
          VG_(message)(Vg_DebugMsg, "TT/TC: recycle sector %d\n", sno);
@@ -1847,7 +1850,7 @@ void VG_(add_to_transtab)( const VexGuestExtents* vge,
 
    // Point an htt entry to the tt slot
    HTTno htti = HASH_TT(entry);
-   vg_assert(htti >= 0 && htti < N_HTTES_PER_SECTOR);
+   vg_assert(htti < N_HTTES_PER_SECTOR);
    while (True) {
       if (sectors[y].htt[htti] == HTT_EMPTY
           || sectors[y].htt[htti] == HTT_DELETED)
@@ -1922,7 +1925,7 @@ Bool VG_(search_transtab) ( /*OUT*/Addr*  res_hcode,
       all sectors and avoids multiple expensive % operations. */
    n_full_lookups++;
    kstart = HASH_TT(guest_addr);
-   vg_assert(kstart >= 0 && kstart < N_HTTES_PER_SECTOR);
+   vg_assert(kstart < N_HTTES_PER_SECTOR);
 
    /* Search in all the sectors,using sector_search_order[] as a
       heuristic guide as to what order to visit the sectors. */
@@ -1981,7 +1984,7 @@ Bool VG_(search_transtab) ( /*OUT*/Addr*  res_hcode,
 /*-------------------------------------------------------------*/
 
 /* forward */
-static void unredir_discard_translations( Addr, ULong );
+static void unredir_discard_translations( Addr /*guest_start*/, ULong  /*range*/);
 
 /* Stuff for deleting translations which intersect with a given
    address range.  Unfortunately, to make this run at a reasonable
@@ -2026,7 +2029,7 @@ static void delete_tte ( /*OUT*/Addr* ga_deleted,
    /* sec and secNo are mutually redundant; cross-check. */
    vg_assert(sec == &sectors[secNo]);
 
-   vg_assert(tteno >= 0 && tteno < N_TTES_PER_SECTOR);
+   vg_assert(tteno < N_TTES_PER_SECTOR);
    TTEntryC* tteC = &sec->ttC[tteno];
    TTEntryH* tteH = &sec->ttH[tteno];
    vg_assert(tteH->status == InUse);
@@ -2043,7 +2046,7 @@ static void delete_tte ( /*OUT*/Addr* ga_deleted,
    for (i = 0; i < tteC->n_tte2ec; i++) {
       ec_num = tteC->tte2ec_ec[i];
       ec_idx = tteC->tte2ec_ix[i];
-      vg_assert(ec_num >= 0 && ec_num < ECLASS_N);
+      vg_assert(ec_num < ECLASS_N);
       vg_assert(ec_idx >= 0);
       vg_assert(ec_idx < sec->ec2tte_used[ec_num]);
       /* Assert that the two links point at each other. */
@@ -2058,7 +2061,7 @@ static void delete_tte ( /*OUT*/Addr* ga_deleted,
       adding a reference from tte to its hash position in tt. */
    HTTno j;
    HTTno k = HASH_TT(tteC->entry);
-   vg_assert(k >= 0 && k < N_HTTES_PER_SECTOR);
+   vg_assert(k < N_HTTES_PER_SECTOR);
    for (j = 0; j < N_HTTES_PER_SECTOR; j++) {
       if (sec->htt[k] == tteno)
          break;
@@ -2101,7 +2104,7 @@ SizeT delete_translations_in_sector_eclass ( /*OUT*/Addr* ga_deleted,
    TTEno    tteno;
    SizeT    numDeld = 0;
 
-   vg_assert(ec >= 0 && ec < ECLASS_N);
+   vg_assert(ec < ECLASS_N);
 
    for (i = 0; i < sec->ec2tte_used[ec]; i++) {
 
@@ -2234,7 +2237,7 @@ void VG_(discard_translations) ( Addr guest_start, ULong range,
                        "                    FAST, ec = %d\n", ec);
 
       /* Fast scheme */
-      vg_assert(ec >= 0 && ec < ECLASS_MISC);
+      vg_assert(ec < ECLASS_MISC);
 
       for (sno = 0; sno < n_sectors; sno++) {
          sec = &sectors[sno];
@@ -2340,7 +2343,7 @@ void VG_(discard_translations_safely) ( Addr  start, SizeT len,
 #define UNREDIR_SZB   1000
 
 #define N_UNREDIR_TT  500
-#define N_UNREDIR_TCQ (N_UNREDIR_TT * UNREDIR_SZB / sizeof(ULong))
+#define N_UNREDIR_TCQ (N_UNREDIR_TT * UNREDIR_SZB / (Int)sizeof(ULong))
 
 typedef
    struct {
@@ -2371,7 +2374,7 @@ static void init_unredir_tt_tc ( void )
                        ( N_UNREDIR_TT * UNREDIR_SZB );
       if (sr_isError(sres)) {
          VG_(out_of_memory_NORETURN)("init_unredir_tt_tc",
-                                     N_UNREDIR_TT * UNREDIR_SZB);
+                                     N_UNREDIR_TT * UNREDIR_SZB, sr_Err(sres));
          /*NOTREACHED*/
       }
       unredir_tc = (ULong *)(Addr)sr_Res(sres);
@@ -2664,12 +2667,12 @@ static Double safe_idiv( ULong a, ULong b )
    return (b == 0 ? 0 : (Double)a / (Double)b);
 }
 
-UInt VG_(get_bbs_translated) ( void )
+ULong VG_(get_bbs_translated) ( void )
 {
    return n_in_count;
 }
 
-UInt VG_(get_bbs_discarded_or_dumped) ( void )
+ULong VG_(get_bbs_discarded_or_dumped) ( void )
 {
    return n_disc_count + n_dump_count;
 }
