@@ -41,6 +41,7 @@
 #include "pub_core_machine.h"       // VG_ELF_CLASS (XXX: which should be moved)
 #include "pub_core_mallocfree.h"    // VG_(malloc), VG_(free)
 #include "pub_core_syscall.h"       // VG_(strerror)
+#include "pub_core_clientstate.h"
 #include "pub_core_ume.h"           // self
 
 #include "priv_ume.h"
@@ -857,6 +858,10 @@ Int VG_(load_macho)(Int fd, const HChar *name, ExeInfo *info)
 
    info->executable_path = VG_(strdup)("ume.macho.executable_path", name);
 
+   SysRes res = VG_(dup)(fd);
+   if (!sr_isError(res))
+      VG_(cl_exec_fd) = sr_Res(res);
+
    return 0;
 }
 
