@@ -9,13 +9,13 @@
    This file is part of Valgrind, a dynamic binary instrumentation
    framework.
 
-   Copyright (C) 2007-2015 Julian Seward
+   Copyright (C) 2007-2017 Julian Seward
       jseward@acm.org
 
    This code is based on previous work by Nicholas Nethercote
    (coregrind/m_oset.c) which is
 
-   Copyright (C) 2005-2015 Nicholas Nethercote
+   Copyright (C) 2005-2017 Nicholas Nethercote
        njn@valgrind.org
 
    which in turn was derived partially from:
@@ -42,9 +42,7 @@
    General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-   02111-1307, USA.
+   along with this program; if not, see <http://www.gnu.org/licenses/>.
 
    The GNU General Public License is contained in the file COPYING.
 */
@@ -93,7 +91,7 @@ struct _WordFM {
 /* forward */
 static Bool avl_removeroot_wrk(AvlNode** t, Word(*kCmp)(UWord,UWord));
 
-/* Swing to the left.  Warning: no balance maintainance. */
+/* Swing to the left.  Warning: no balance maintenance. */
 static void avl_swl ( AvlNode** root )
 {
    AvlNode* a  = *root;
@@ -103,7 +101,7 @@ static void avl_swl ( AvlNode** root )
    b->child[0] = a;
 }
 
-/* Swing to the right.  Warning: no balance maintainance. */
+/* Swing to the right.  Warning: no balance maintenance. */
 static void avl_swr ( AvlNode** root )
 {
    AvlNode* a  = *root;
@@ -113,7 +111,7 @@ static void avl_swr ( AvlNode** root )
    b->child[1] = a;
 }
 
-/* Balance maintainance after especially nasty swings. */
+/* Balance maintenance after especially nasty swings. */
 static void avl_nasty ( AvlNode* root )
 {
    switch (root->balance) {
