@@ -60,7 +60,7 @@ extern void VG_(di_initialise) ( void );
    released by simply re-opening and closing the same file (even via
    different fd!).
 */
-#if defined(VGO_linux) || defined(VGO_darwin) || defined(VGO_solaris)
+#if defined(VGO_linux) || defined(VGO_darwin) || defined(VGO_solaris) || defined(VGO_freebsd)
 extern ULong VG_(di_notify_mmap)( Addr a, Bool allow_SkFileV, Int use_fd );
 
 extern void VG_(di_notify_munmap)( Addr a, SizeT len );
@@ -76,6 +76,12 @@ extern void VG_(di_notify_pdb_debuginfo)( Int fd, Addr avma,
 extern void VG_(di_notify_vm_protect)( Addr a, SizeT len, UInt prot );
 #endif
 
+extern void VG_(addr_load_di)( Addr a );
+
+extern void VG_(di_load_di)( DebugInfo *di );
+
+extern void VG_(load_di)( DebugInfo *di, Addr a );
+
 extern void VG_(di_discard_ALL_debuginfo)( void );
 
 /* Like VG_(get_fnname), but it does not do C++ demangling nor Z-demangling
@@ -128,6 +134,10 @@ typedef
             Addr f4; Addr f5; Addr f6; Addr f7; }
    D3UnwindRegs;
 #elif defined(VGA_mips32) || defined(VGA_mips64) || defined(VGA_nanomips)
+typedef
+   struct { Addr pc; Addr sp; Addr fp; Addr ra; }
+   D3UnwindRegs;
+#elif defined(VGA_riscv64)
 typedef
    struct { Addr pc; Addr sp; Addr fp; Addr ra; }
    D3UnwindRegs;
@@ -146,6 +156,15 @@ extern Bool VG_(use_CF_info) ( /*MOD*/D3UnwindRegs* uregs,
    info (e.g. CFI info or FPO info or ...). */
 extern UInt VG_(debuginfo_generation) (void);
 
+#if defined(VGO_freebsd)
+/* Force completion of loading all debuginfo.
+    Needed on FreeBSD when entering capability mode since
+    we can't open executable files to get the debuginfo after
+    entering capability mode. */
+extern void VG_(load_all_debuginfo) (void);
+/* Get the size of .data for the client exe */
+extern SizeT VG_(data_size)(void);
+#endif
 
 
 /* True if some FPO information is loaded.
