@@ -86,9 +86,8 @@ extern void VG_(do_atfork_parent) ( ThreadId tid );
 extern void VG_(do_atfork_child)  ( ThreadId tid );
 
 #if defined(VGO_freebsd)
-// sysctl, modfind
+// sysctlbyname, getosreldate, is32on64
 extern Int VG_(sysctlbyname)(const HChar *name, void *oldp, SizeT *oldlenp, const void *newp, SizeT newlen);
-extern Int VG_(getosreldate)(void);
 extern Bool VG_(is32on64)(void);
 
 struct auxv {
