@@ -1681,7 +1681,7 @@ ULong DRD_(thread_get_discard_ordered_segments_count)(void)
 }
 
 /** Return how many times the conflict set has been updated entirely. */
-ULong DRD_(thread_get_compute_conflict_set_count)()
+ULong DRD_(thread_get_compute_conflict_set_count)(void)
 {
    return s_compute_conflict_set_count;
 }
