@@ -1,7 +1,7 @@
 /*
   This file is part of drd, a thread error detector.
 
-  Copyright (C) 2006-2017 Bart Van Assche <bvanassche@acm.org>.
+  Copyright (C) 2006-2020 Bart Van Assche <bvanassche@acm.org>.
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
@@ -72,7 +72,7 @@ void DRD_(vc_init)(VectorClock* const vc,
                    const VCElem* const vcelem,
                    const unsigned size);
 void DRD_(vc_cleanup)(VectorClock* const vc);
-void DRD_(vc_copy)(VectorClock* const new, const VectorClock* const rhs);
+void DRD_(vc_copy)(VectorClock* const obj, const VectorClock* const rhs);
 void DRD_(vc_assign)(VectorClock* const lhs, const VectorClock* const rhs);
 void DRD_(vc_increment)(VectorClock* const vc, DrdThreadId const tid);
 static __inline__
