@@ -7,7 +7,7 @@
    This file is part of Valgrind, a dynamic binary instrumentation
    framework.
 
-   Copyright (C) 2005-2013 Julian Seward
+   Copyright (C) 2005-2017 Julian Seward
       jseward@acm.org
 
    This program is free software; you can redistribute it and/or
@@ -21,9 +21,7 @@
    General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-   02111-1307, USA.
+   along with this program; if not, see <http://www.gnu.org/licenses/>.
 
    The GNU General Public License is contained in the file COPYING.
 */
@@ -337,6 +335,14 @@ struct vki_sigcontext {
   long             vmx_reserve[VKI_ELF_NVRREG+VKI_ELF_NVRREG+1];
 };
 
+//----------------------------------------------------------------------
+// From linux-5.0.0/arch/powerpc/include/uapi/asm/siginfo.h
+//----------------------------------------------------------------------
+
+#ifdef __powerpc64__
+# define __VKI_ARCH_SI_PREAMBLE_SIZE     (4 * sizeof(int))
+#endif
+
 //----------------------------------------------------------------------
 // From linux-2.6.13/include/asm-ppc64/mman.h
 //----------------------------------------------------------------------
@@ -371,6 +377,7 @@ struct vki_sigcontext {
 #define VKI_O_TRUNC           01000 /* not fcntl */
 #define VKI_O_APPEND          02000
 #define VKI_O_NONBLOCK        04000
+#define VKI_O_DIRECT        0400000
 #define VKI_O_LARGEFILE     0200000
 
 #define VKI_AT_FDCWD            -100
@@ -685,6 +692,9 @@ struct vki_ucontext {
   struct vki_sigcontext uc_mcontext;  /* last for extensibility */
 };
 
+// CAB: TODO
+typedef char vki_modify_ldt_t;
+
 //----------------------------------------------------------------------
 // From linux-2.6.13/include/asm-ppc64/ipcbuf.h
 //----------------------------------------------------------------------
@@ -794,6 +804,13 @@ struct vki_shminfo64 {
 #define	VKI_ENOSYS       38  /* Function not implemented */
 #define	VKI_EOVERFLOW    75  /* Value too large for defined data type */
 
+//----------------------------------------------------------------------
+// From linux-3.19.0/arch/powerpc/include/uapi/asm/ioctls.h
+//----------------------------------------------------------------------
+
+#define VKI_TIOCGSERIAL     0x541E
+#define VKI_TIOCSSERIAL     0x541F
+
 //----------------------------------------------------------------------
 // end
 //----------------------------------------------------------------------
