@@ -5,7 +5,7 @@
 #include <unistd.h>
 #include <sched.h>
 #include <signal.h>
-#include <linux/mman.h> // MREMAP_FIXED
+#include <sys/mman.h> // MREMAP_FIXED
 #include <sys/prctl.h>
 
 // Here we are trying to trigger every syscall error (scalar errors and
@@ -137,7 +137,7 @@ int main(void)
 
    // __NR_mount 21
    GO(__NR_mount, "5s 3m");
-   SY(__NR_mount, x0, x0, x0, x0, x0); FAIL;
+   SY(__NR_mount, x0, x0, x0-1, x0, x0); FAIL;
    
    // __NR_umount 22
    GO(__NR_umount, "1s 1m");
@@ -269,7 +269,7 @@ int main(void)
    SY(__NR_lock); FAIL;
 
    // __NR_ioctl 54
-   #include <asm/ioctls.h>
+   #include <sys/ioctl.h>
    GO(__NR_ioctl, "3s 1m");
    SY(__NR_ioctl, x0, x0+TCSETS, x0); FAIL;
 
