@@ -12,9 +12,14 @@ struct Test
 
 int main()
 {
+#if defined(__sun__)
+    const auto alignment_mask{0x7UL};
+#else
+    const auto alignment_mask{0xfUL};
+#endif
     std::unique_ptr<Test> test = std::make_unique<Test>();
     //std::cerr << "test " << test.get() << ' ' << (reinterpret_cast<size_t>(test.get()) & 0xfUL) << '\n';
-    assert((reinterpret_cast<size_t>(test.get()) & 0xfUL) == 0);
+    assert((reinterpret_cast<size_t>(test.get()) & alignment_mask) == 0);
 }
 
     
