@@ -13,9 +13,7 @@
  General Public License for more details.
 
  You should have received a copy of the GNU General Public License
- along with this program; if not, write to the Free Software
- Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
- 02111-1307, USA.
+ along with this program; if not, see <http://www.gnu.org/licenses/>.
 
  The GNU General Public License is contained in the file COPYING.
  */
@@ -1258,6 +1256,8 @@ int main() {
       i++;
    }
 
+#else
+   printf("HAS_DFP not detected.\n");
 #endif // HAS_DFP
    return 0;
 }
