@@ -18,17 +18,13 @@
    Boston, MA 02111-1307, USA.  */
 
 #include <errno.h>
-#if !defined(__APPLE__) && !defined(__sun)
-# include <error.h>
-#endif
 #include <stdlib.h>
 #include <pthread.h>
 #include <unistd.h>
 #include <sys/wait.h>
 #include <stdio.h>
-
-#if defined(__APPLE__) || defined(__sun)
 #include <string.h>  /* strerror */
+
 static void error (int status, int errnum, char* msg)
 {
    fprintf(stderr, "%s%s%s\n",
@@ -38,7 +34,6 @@ static void error (int status, int errnum, char* msg)
    if (errnum)
       exit(errnum);
 }
-#endif
 
 enum
 {
