@@ -859,12 +859,15 @@ while (<>)
     print qq|$prefix\"m\" \(state[0]\)\n|;
 
     $prefix = "         : ";
+    my %clobber_added;
 
-    foreach my $arg (@presets, @args)
+    foreach my $arg (@presets, @results, @args)
     {
-        if ($arg->{register} && $arg->{type} ne "st")
+        my $register = $arg->{register};
+
+        if ($register && $arg->{type} ne "st" && !$clobber_added{$register}++)
         {
-            print qq|$prefix\"$arg->{register}\"|;
+            print qq|$prefix\"$register\"|;
             $prefix = ", ";
         }
     }
