@@ -24,6 +24,8 @@ char* all_OSes[] = {
    "linux",
    "darwin",
    "solaris",
+   "freebsd",
+   "illumos",
    NULL
 };
 
@@ -65,6 +67,10 @@ static Bool go(char* OS, char *min_version)
 
 #elif defined(VGO_solaris)
    if ( 0 == strcmp( OS, "solaris" ) ) return True;
+   if ( 0 == strcmp( OS, "illumos" ) ) return True;
+
+#elif defined(VGO_freebsd)
+   if ( 0 == strcmp( OS, "freebsd" ) ) return True;
 
 #else
 #  error Unknown OS
